import BaseFormComponent from "@/customForm/entity/base";
import styles from "./index.module.css";
import { Col, Flex, Row, Space } from "antd";
import { useEffect, useMemo, useState } from "react";
import RenderComponent from "@/components/FormComponentRender/renderComponent";
import { cloneDeep, isEqual } from "lodash";

interface GroupProps {
  value: boolean | string;
  onChange?: (value: Record<string, any>[]) => void;
  children?: BaseFormComponent[];
  /** 是否无限层级  */
  isInfinite?: boolean;

  metaData: BaseFormComponent;
}

export default function (props: GroupProps) {
  const { value, onChange, children, isInfinite, metaData } = props;

  const [groupData, setGroupData] = useState<Record<string, any>[]>([{}]);

  const defValue = useMemo(() => {
    const result: { [key: string]: undefined } = {};
    children?.forEach((v) => {
      result[v.key] = undefined;
    });
    return result;
  }, [children]);

  useEffect(() => {
    if (typeof value === "object" && !isEqual(value, groupData)) {
      setGroupData(value);
    }
  }, [value]);

  /**
   * 初始化
   */
  useEffect(() => {
    setGroupData([defValue]);
  }, [children, defValue]);
  const onAdd = (i: number) => {
    const cur = cloneDeep(groupData);
    cur.splice(i + 1, 0, defValue);
    setGroupData(cur);
  };

  const onRemove = (i: number) => {
    setGroupData(groupData.filter((_, index) => index !== i));
  };
  const valueChange = (v: any, key: string, index: number) => {
    const newData = groupData.map((item, i) => {
      if (i === index) {
        return { ...item, [key]: v.target?.value ?? v };
      }
      return item;
    });
    onChange && onChange(newData);
    setGroupData(newData);
  };
  console.log(groupData);
  return (
    <div className={styles.container}>
      {groupData.map((item, i) => {
        return (
          <div>
            <Flex
              className={styles.groupTitle}
              align="center"
              justify="space-between"
              key={i}
            >
              <div>
                {metaData.label}
                {i + 1}
              </div>
              <div>
                <Space>
                  {isInfinite && <a onClick={() => onAdd(i)}>新增</a>}
                  {i != 0 && <a onClick={() => onRemove(i)}>删除</a>}
                </Space>
              </div>
            </Flex>
            {children?.map((configItem) => {
              return (
                <Row style={{ margin: "8px 0" }} align={"middle"}>
                  <Col
                    span={6}
                    style={{ textAlign: "right", paddingRight: 12 }}
                  >
                    {configItem.label}
                  </Col>
                  <Col span={18}>
                    <RenderComponent
                      config={configItem.componentOption}
                      componentType={configItem.componentType}
                      metaData={configItem}
                      onChange={(v) => {
                        valueChange(v, configItem.key, i);
                      }}
                      value={item[configItem.key]}
                    ></RenderComponent>
                  </Col>
                </Row>
              );
            })}
          </div>
        );
      })}
      <div className={styles.card}></div>
    </div>
  );
}
