import { MinusOutlined, PlusOutlined } from "@ant-design/icons";
import { Button, Flex, Input } from "antd";
import { cloneDeep } from "lodash";
import { useEffect, useState } from "react";

interface ListProps {
  value: string[];
  onChange: (params: string[]) => void;
}

const List = (props: ListProps) => {
  const { value, onChange } = props;
  const [data, setData] = useState([""]);

  useEffect(() => {
    if (value && Array.isArray(value) && value.length > 0) {
      setData(value);
    } else {
      setData([""]);
    }
  }, [value]);

  const add = (index: number) => {
    const temp = cloneDeep(data);
    temp.splice(index + 1, 0, "");
    setData(temp);
  };

  const deleteItem = (index: number) => {
    const temp = cloneDeep(data);
    temp.splice(index, 1);
    setData(temp);
  };
  const LabelChange = (e: any, index: number) => {
    const v = e.target.value;
    const temp = cloneDeep(data);
    temp[index] = v;
    setData(temp);
    if (temp.length === 0 && v === "") {
      onChange([]);
    } else onChange(temp);
  };

  return (
    <div>
      {data.map((item, i) => {
        return (
          <Flex gap={12} key={i} style={{ marginBottom: 12 }}>
            <Input
              placeholder="请填写选项"
              value={item}
              onChange={(e: any) => LabelChange(e, i)}
            ></Input>
            <Button
              icon={<PlusOutlined />}
              shape="circle"
              onClick={add.bind(this, i)}
            ></Button>
            {i != 0 && (
              <Button
                icon={<MinusOutlined />}
                shape="circle"
                onClick={deleteItem.bind(this, i)}
              ></Button>
            )}
          </Flex>
        );
      })}
    </div>
  );
};

export default List;
