import {
  Button,
  Dropdown,
  Flex,
  Form,
  Input,
  MenuProps,
  Space,
  message,
} from "antd";
import BasicModal from "@/components/BasicModal";
import avatarIcon from "@/assets/images/user/avatar.png";
import styles from "./adminLogin.module.css";
import { useBoolean } from "ahooks";
import service from "@/service";
import useUserStore from "@/store/useUserStore";
import { LogoutOutlined } from "@ant-design/icons";
import eventBus from "@/utils/eventBus";
import { useLocation } from "react-router-dom";
import { useEffect } from "react";
import { Base64 } from "js-base64";
import { encryption } from "@/utils";
const AdminLogin: React.FC = () => {
  const [visible, { setFalse, setTrue }] = useBoolean(false);
  const [form] = Form.useForm<{
    username: string;
    password: string;
  }>();
  const { adminInfo, updateAdminInfo } = useUserStore();
  const location = useLocation();

  /** 免登录 */
  useEffect(() => {
    const search = location.search;
    const params = new URLSearchParams(search);
    const tokenBase64 = params.get("token");
    if (tokenBase64) {
      const token = Base64.decode(tokenBase64);
      localStorage.setItem("admin_token", token);
      service.loginService.getStaffInfo().then((userRes) => {
        if (userRes.code === 200) {
          updateAdminInfo(userRes.data);
          setFalse();
          eventBus.emit("updateList");
        }
      });
    }
  }, [location]);

  const onFinish = (values: any) => {
    const params = {
      ...values,
    };

    params.password = encryption(values.password || "", "thanks,hncycloud");

    service.loginService.getToken(params).then((res) => {
      if (res.code === 200) {
        /** 存储token */
        localStorage.setItem("admin_token", res.data.access_token);
        /** 以用户平台的token获取本身平台的信息 */
        service.loginService.getStaffInfo().then((userRes) => {
          if (userRes.code === 200) {
            updateAdminInfo(userRes.data);
            setFalse();
            eventBus.emit("updateList");
            message.success("登录成功！");
          }
        });
      }
    });
  };
  const items: MenuProps["items"] = [
    {
      key: "1",
      label: (
        <Space>
          <LogoutOutlined />
          退出登录
        </Space>
      ),
    },
  ];
  const onLogout = (item: any) => {
    if (item.key === "1") {
      updateAdminInfo(undefined);
      localStorage.removeItem("admin_token");
      message.success("退出成功");
      eventBus.emit("updateList");
    }
  };
  return (
    <>
      {adminInfo ? (
        <Space size="large">
          <Dropdown menu={{ items, onClick: onLogout }}>
            <Flex align="center">
              <img src={avatarIcon} alt="" style={{ width: 55, height: 55 }} />
              <div>{adminInfo?.nickname}</div>
            </Flex>
          </Dropdown>
        </Space>
      ) : (
        <Button onClick={setTrue} type="primary" style={{ marginLeft: 12 }}>
          登录
        </Button>
      )}

      <BasicModal
        width={1155}
        visible={visible}
        height={739}
        onClose={setFalse}
        contentStyle={{ borderRadius: 10 }}
      >
        <div className={styles.container}>
          <div></div>
          <div>
            <div className={styles.title}>欢迎登录</div>
            <div>
              <Form
                layout="vertical"
                form={form}
                requiredMark={false}
                initialValues={{
                  username: "12400000106",
                  password: "zhrc@123",
                }}
                onFinish={onFinish}
              >
                <Form.Item
                  hasFeedback
                  label="账号"
                  name="username"
                  validateDebounce={1000}
                  rules={[{ required: true, message: "请输入账号" }]}
                >
                  <Input placeholder="请输入账号" size="large" />
                </Form.Item>
                <Form.Item
                  hasFeedback
                  label="密码"
                  name="password"
                  validateDebounce={1000}
                  rules={[{ required: true, message: "请输入密码" }]}
                >
                  <Input.Password placeholder="请输入密码" size="large" />
                </Form.Item>
                <Form.Item>
                  <Button
                    type="primary"
                    shape="round"
                    onClick={form.submit}
                    style={{ width: 120, height: 46 }}
                  >
                    登录
                  </Button>
                </Form.Item>
              </Form>
            </div>
          </div>
        </div>
      </BasicModal>
    </>
  );
};

export default AdminLogin;
