import RenderComponent from "@/components/FormComponentRender/renderComponent";
import { ComponentsType } from "@/customForm/interfaces";
import { Button, Flex, Form, Input } from "antd";
import FormSelect from "./components/formSelect";
import styles from "./examineNodeSetting.module.css";
import { useEffect, useState } from "react";
import { isEqual } from "lodash";

const ActionDescChange = (props: {
  value: string[];
  onChange: (value: string[]) => void;
}) => {
  const [value, setValue] = useState<string[]>([]);

  const inputChange = (
    e: React.ChangeEvent<HTMLInputElement>,
    index: number
  ) => {
    const str = e.target.value;
    const newValue = [...value];
    newValue[index] = str;
    setValue(newValue);
    props.onChange(newValue);
  };

  useEffect(() => {
    if (!isEqual(props.value, value)) {
      setValue(props.value);
    }
  }, [props.value]);

  return (
    <Flex gap={12}>
      <div>
        <div style={{ marginBottom: 8 }}>正向操作</div>
        <Input
          value={value?.[0]}
          size="large"
          onChange={(e) => inputChange(e, 0)}
        ></Input>
      </div>
      <div>
        <div style={{ marginBottom: 8 }}>逆向操作</div>
        <Input
          value={value?.[1]}
          onChange={(e) => inputChange(e, 1)}
          size="large"
        ></Input>
      </div>
    </Flex>
  );
};

interface ExamineNodeSettingProps {
  onUpdate: (value: any) => void;
  value: any;
}
const ExamineNodeSetting = (props: ExamineNodeSettingProps) => {
  const { onUpdate, value } = props;

  const FormConfig = [
    {
      label: "审批节点名称",
      componentType: "TextInput",
      key: "elementAlias",
      config: {
        placeholder: "请输入",
        size: "large",
      },
    },
    {
      label: "节点图标",
      componentType: "ImgUpload",
      key: "icon",
      config: {
        placeholder: "请上传图标",
      },
    },
    {
      label: "指定审批人",
      componentType: "UserSelect",
      key: "approverList",
      config: {
        placeholder: "请输入",
      },
    },
    {
      label: "",
      //@ts-ignore
      component: <ActionDescChange />,
      key: "forwardAndReverseName",
    },
    {
      label: "审批内容",
      //@ts-ignore
      component: <FormSelect />,
      key: "examineKeys",
    },
  ];
  const [form] = Form.useForm();

  useEffect(() => {
    if (value) {
      form.setFieldsValue(value);
    }
  }, [value]);
  const onFinish = (values: any) => {
    onUpdate(values);
  };
  return (
    <div className={styles.container}>
      <div className={styles.content}>
        <div className={styles.title}>添加审批节点</div>
        <Form form={form} colon={false} layout="vertical" onFinish={onFinish}>
          {FormConfig.map((item) => {
            return (
              <Form.Item
                label={item.label}
                name={item.key}
                required={false}
                rules={[
                  {
                    required: true,
                    message: `请设置${item?.label}`,
                  },
                ]}
              >
                {item.component ? (
                  item.component
                ) : (
                  <RenderComponent
                    config={item.config}
                    componentType={item.componentType as ComponentsType}
                  ></RenderComponent>
                )}
              </Form.Item>
            );
          })}
          <Form.Item>
            <Button type="primary" htmlType="submit">
              保存
            </Button>
          </Form.Item>
        </Form>
      </div>
    </div>
  );
};

export default ExamineNodeSetting;
