import { Button, Empty, Modal, Popover, message, notification } from "antd";
import styles from "./index.module.css";
import plus from "@/assets/images/setting/plus.png";
import { CloseOutlined, RightOutlined } from "@ant-design/icons";
import { useEffect, useState } from "react";
import { useFormContext } from "..";
import { FlowChartNode } from "../interface";
import ExamineNodeSetting from "./examineNodeSetting";
import ApplyForNodeSetting from "./applyForNodeSetting";
import TransactNodeSetting from "./transactNodeSetting";
import classNames from "classnames";
import service from "@/service";
import eventBus from "@/utils/eventBus";
import { buildLineData, getDefaultNodeByType } from "../util";
import useGlobalData from "@/store/useGlobalData";

/** 结束节点 */
const EndNodeRender = () => {
  return <div className={styles.endNode}>流程结束</div>;
};

interface LineNodeRenderProps {
  add: (type: "办理" | "审批") => void;
}
/** 线节点 */
const LineNodeRender = (props: LineNodeRenderProps) => {
  const { add } = props;
  return (
    <div className={styles.lineNode}>
      <Popover
        placement="right"
        arrow={false}
        content={
          <div>
            <Button type="text" onClick={add.bind(this, "办理")}>
              办理
            </Button>
            <Button type="text" onClick={add.bind(this, "审批")}>
              审批
            </Button>
          </div>
        }
      >
        <div className={styles.actionBtn}>
          <img src={plus} alt="" style={{ width: 40, height: 40 }}></img>
        </div>
      </Popover>
    </div>
  );
};

type BaseNodeProps = {
  title: string;
  content: string;
  clickHandle?: () => void;
  showClose?: boolean;
  onClose?: () => void;
  active: boolean;
};
/** 基础节点 */
const BaseNodeRender = (props: BaseNodeProps) => {
  const {
    title,
    content,
    clickHandle,
    showClose = true,
    active = false,
    onClose,
  } = props;
  return (
    <div className={styles.baseNode}>
      <div className={styles.decorator}></div>
      <div className={styles.baseNodeHeader}>
        <div>{title}</div>
        {showClose && (
          <Button
            type="text"
            shape="circle"
            icon={<CloseOutlined />}
            onClick={onClose}
          ></Button>
        )}
      </div>
      <div
        className={classNames(styles.baseNodeContent, active && styles.active)}
        onClick={clickHandle}
      >
        <div>{content}</div>
        <RightOutlined />
      </div>
    </div>
  );
};

const Flow = () => {
  /** 当前操作对象 */
  const [actionNode, setActionNode] = useState<any>();

  /** 流程图数据   */
  const { flowData, setFlowData, baseInfo, mode, flowMetaData } =
    useFormContext();
  const { mainBodyTypes } = useGlobalData();

  useEffect(() => {
    if (flowData.length === 0) {
      const newValue = [getDefaultNodeByType(1), getDefaultNodeByType()];
      setFlowData(newValue as any);
      setActionNode(newValue[0]);
    }
  }, []);

  const openNotification = (message: string) => {
    notification.open({
      message: message,
      description: "",
      type: "success",
      duration: 2,
    });
  };

  const addElement = (index: number, type: "办理" | "审批") => {
    let node;
    if (type === "办理") {
      node = getDefaultNodeByType(2);
    } else {
      node = getDefaultNodeByType(3);
    }
    setFlowData((pre) => {
      const newData = [...pre];
      newData.splice(index + 1, 0, node as any);
      return newData;
    });
  };

  /** 删除节点 */
  const deleteNode = (index: number) => {
    if (mode === "edit") {
      Modal.confirm({
        title: "是否删除节点？",
        content: "删除节点会影响到正在审批的用户，请确认是否删除",
        okText: "确认",
        cancelText: "取消",
        centered: true,
        onOk() {
          if (flowData[index].elementId === actionNode?.elementId) {
            setActionNode(undefined);
          }
          setFlowData((pre) => {
            const newData = [...pre];
            newData.splice(index, 1);
            return newData;
          });
        },
        onCancel() {
          console.log("Cancel");
        },
      });
    } else {
      if (flowData[index].elementId === actionNode?.elementId) {
        setActionNode(undefined);
      }
      setFlowData((pre) => {
        const newData = [...pre];
        newData.splice(index, 1);
        return newData;
      });
    }
  };

  const renderNode = (item: FlowChartNode, index: number) => {
    if ([1, 2, 3].includes(item.nodeType as number)) {
      let content = "去设置";
      // if (item.nodeType === 1) {
      //   content = item.scopeOfApplication ?? "去设置";
      // }

      return (
        <>
          <BaseNodeRender
            active={actionNode?.elementId === item.elementId}
            title={item?.elementAlias ?? item.elementName}
            content={content}
            onClose={() => deleteNode(index)}
            clickHandle={() => {
              setActionNode(item);
            }}
            showClose={item.nodeType != 1}
          ></BaseNodeRender>
          <LineNodeRender
            add={(type) => {
              addElement(index, type);
            }}
          ></LineNodeRender>
        </>
      );
    }
    return <EndNodeRender></EndNodeRender>;
  };

  const onUpdate = (params: any) => {
    for (const key in params) {
      actionNode[key] = params[key];
    }

    setFlowData((pre) => {
      const newData = [...pre];
      const index = newData.findIndex(
        (item) => item.elementId === actionNode.elementId
      );
      newData[index] = actionNode;
      return newData;
    });
    openNotification("已更新节点信息");
  };

  const onSave = () => {
    const metaData =
      mode === "edit"
        ? flowMetaData.current
        : {
            processId: baseInfo?.processId,
            processName: baseInfo?.thingName,
            description: "",
          };

    const lineData = buildLineData(flowData);
    let ErrObj = { status: false, objName: "", scopeStatus: false };

    const nodeList = flowData?.map((v) => {
      const temp = { ...v };
      temp.forwardAndReverseName = (
        temp.forwardAndReverseName as string[]
      )?.join(",");

      if (v.nodeType === 1) {
        const scopeKeys = temp.scopeOfApplication?.split(",");
        temp.scopeCodeOfApplication = scopeKeys
          ?.map((v) => {
            return mainBodyTypes.find((body) => body.id === v)?.name;
          })
          .join(",");
        if (scopeKeys?.length == 0) {
          ErrObj.scopeStatus = true;
        }
      }

      if (v.nodeType === 3 || v.nodeType === 2) {
        if (!temp.approverList || temp.approverList.length === 0) {
          ErrObj.status = true;
          ErrObj.objName = temp?.elementAlias ?? "";
        }
        temp.approverList = (temp.approverList as unknown as string[])?.join(
          ","
        );
      }

      return temp;
    });
    /** 检验 */
    if (ErrObj.status) {
      message.warning(`${ErrObj.objName}节点缺少处理人员，请检查节点配置`);
      return;
    }
    if (ErrObj.scopeStatus) {
      message.warning(`节点缺少申请范围，请检查节点配置`);
      return;
    }

    const params = {
      ...metaData,
      elementParams: [
        {
          elementId: "startEvent",
          elementName: "开始节点",
          elementType: 1,
        },
        ...nodeList,
        ...lineData,
      ],
    };

    service.settingService.saveFlowConfig(params as any).then((res) => {
      if (res.code === 200) {
        openNotification(mode === "add" ? "创建成功" : "修改成功");
        eventBus.emit("updateList");
      }
    });
  };

  return (
    <div className={styles.container}>
      <div className={styles.contentWrapper}>
        <div className={styles.flowChartContent}>
          {flowData?.map((item, index) => {
            return renderNode(item, index);
          })}
        </div>
        <div className={styles.settingContent}>
          {actionNode?.nodeType === 1 && (
            <ApplyForNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {actionNode?.nodeType === 2 && (
            <TransactNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {actionNode?.nodeType === 3 && (
            <ExamineNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {!actionNode && (
            <div style={{ textAlign: "center", marginTop: 100 }}>
              <Empty description="未选中任意流程节点"></Empty>
            </div>
          )}
        </div>
      </div>
      <div className={styles.footer}>
        <Button
          type="primary"
          style={{ width: 150, height: 50, fontSize: 18 }}
          onClick={onSave}
        >
          确定
        </Button>
      </div>
    </div>
  );
};

export default Flow;
