import RenderComponent from "@/components/FormComponentRender/renderComponent";
import { ComponentsType } from "@/customForm/interfaces";
import { Button, Form } from "antd";
import FormSelect from "./components/formSelect";
import styles from "./transactNodeSetting.module.css";
import { useEffect } from "react";
interface TransactNodeSettingProps {
  onUpdate: (value: any) => void;
  value: any;
}
const TransactNodeSetting = (props: TransactNodeSettingProps) => {
  const { onUpdate, value } = props;

  const FormConfig = [
    {
      label: "办理节点名称",
      componentType: "TextInput",
      key: "elementAlias",
      config: {
        placeholder: "请输入",
        size: "large",
      },
    },
    {
      label: "节点图标",
      componentType: "ImgUpload",
      key: "icon",
      config: {
        placeholder: "请上传图标",
      },
    },
    {
      label: "指定办理人",
      componentType: "UserSelect",
      key: "approverList",
      config: {
        placeholder: "请输入",
      },
    },

    {
      label: "办理内容",
      //@ts-ignore
      component: <FormSelect />,
      key: "examineKeys",
    },
  ];

  const [form] = Form.useForm();
  const onFinish = (values: any) => {
    onUpdate(values);
  };

  useEffect(() => {
    form.setFieldsValue(value);
  }, [value]);
  return (
    <div className={styles.container}>
      <div className={styles.content}>
        <div className={styles.title}>添加办理节点</div>
        <Form form={form} colon={false} layout="vertical" onFinish={onFinish}>
          {FormConfig.map((item) => {
            return (
              <Form.Item
                label={item.label}
                name={item.key}
                required={false}
                rules={[
                  {
                    required: true,
                    message: `请设置${item?.label}`,
                  },
                ]}
              >
                {item.component ? (
                  item.component
                ) : (
                  <RenderComponent
                    config={item.config}
                    componentType={item.componentType as ComponentsType}
                  ></RenderComponent>
                )}
              </Form.Item>
            );
          })}
          <Form.Item>
            <Button type="primary" htmlType="submit">
              保存
            </Button>
          </Form.Item>
        </Form>
      </div>
    </div>
  );
};

export default TransactNodeSetting;
