import BasicModal from "@/components/BasicModal";
import styles from "./index.module.css";
import setting from "@/assets/images/setting/setting.png";
import { ConfigProvider, Tabs } from "antd";
import Basic from "./basic";
import FormMatch from "./FormMatch";
import Flow from "./Flow";
import BaseFormComponent from "@/customForm/entity/base";
import React, { useEffect, useMemo, useRef, useState } from "react";

import { FlowChartNode } from "./interface";
import { Components } from "@/customForm/registry";
import service from "@/service";

import { buildFlowList, deserializeFlowChart } from "./util";

interface FormSettingContextProps {
  /** 表单配置列表 */
  formConfigList: BaseFormComponent[];
  setFormConfigList: React.Dispatch<React.SetStateAction<BaseFormComponent[]>>;
  /** 基础信息 */
  baseInfo?: Record<string, any>;
  setBaseInfo: React.Dispatch<React.SetStateAction<Record<string, any>>>;
  /** 流程图数据 */
  flowData: FlowChartNode[];
  setFlowData: React.Dispatch<React.SetStateAction<FlowChartNode[]>>;
  setActiveKey: any;
  setActiveTabs: React.Dispatch<React.SetStateAction<string[]>>;
  mode: "edit" | "add";
  initialValue: any;
  flowMetaData: any;
}

const FormSettingContext = React.createContext<FormSettingContextProps>(
  {} as FormSettingContextProps
);

export const useFormContext = () => {
  return React.useContext(FormSettingContext);
};

interface SettingProp {
  visible: boolean;
  onClose(): void;
  mode: "add" | "edit";
  initialValue?: any;
}
const Setting = (props: SettingProp) => {
  const { visible, onClose, mode = "add", initialValue } = props;
  const [formConfigList, setFormConfigList] = React.useState<
    BaseFormComponent[]
  >([]);
  const [activeTabs, setActiveTabs] = useState<string[]>(["2"]);
  const [activeKey, setActiveKey] = useState<string>("2");

  const [baseInfo, setBaseInfo] = React.useState<Record<string, any>>();
  /** 流程图数据 */
  const [flowData, setFlowData] = React.useState<FlowChartNode[]>([]);
  const flowMetaData = useRef();

  useEffect(() => {
    if (!visible) {
      /** 清空数据  */
      if (mode === "add") {
        // setBaseInfo(undefined);
        // setFlowData([]);
        // setFormConfigList([]);
        // setActiveKey("1");
        // setActiveTabs(["1"]);
      }
    }
  }, [visible]);

  /** 反序列化 */
  useEffect(() => {
    if (initialValue && mode == "edit") {
      setActiveTabs(["1", "2", "3"]);
      const {
        matterContentList,
        updateAt,
        createAt,
        deleted,
        flowProcessId,
        ...baseFomValue
      } = initialValue;

      setBaseInfo(baseFomValue);

      if (matterContentList) {
        const newFormConfig = (matterContentList as any[])
          .sort((pre, cur) => pre.sort - cur.sort)
          .map((item: any) => {
            const componentType = item.componentType;

            const component = Components.get(componentType);
            //@ts-ignore
            const newEntity = new component();
            newEntity.setValues({
              key: item.fieldKey,
              label: item.label,
              groupId: item.groupId,
            });
            newEntity.componentOption?.update(JSON.parse(item.otherSet));
            return newEntity;
          });
        setFormConfigList(newFormConfig);
      }
      if (flowProcessId) {
        service.settingService.getFlowChartConfig(flowProcessId).then((res) => {
          if (res.code === 200) {
            const flowChartConfig = { ...res.data };
            const { elementParams, ...metaData } = flowChartConfig;
            const originElementList = deserializeFlowChart(elementParams);
            flowMetaData.current = metaData;
            setFlowData(buildFlowList(originElementList));
          }
        });
      }
      // if()
    }
  }, [mode, initialValue]);

  const TABS = useMemo(
    () => [
      {
        label: "基础设置",
        key: "1",
        children: <Basic></Basic>,
        disabled: !activeTabs.includes("1"),
      },
      {
        label: "申请内容",
        key: "2",
        children: <FormMatch></FormMatch>,
        disabled: !activeTabs.includes("2"),
      },
      {
        label: "审批流程",
        key: "3",
        children: <Flow></Flow>,
        disabled: !activeTabs.includes("3"),
      },
    ],
    [activeTabs]
  );

  return (
    <BasicModal
      visible={visible}
      width={1600}
      contentStyle={{ borderRadius: 10 }}
      height={1000}
      onClose={onClose}
    >
      <div className={styles.container}>
        <div className={styles.header}>
          <img src={setting} style={{ width: 46, height: 46 }} alt=""></img>
          <div className={styles.headerTitle}>设置</div>
        </div>
        <FormSettingContext.Provider
          value={{
            formConfigList,
            setFormConfigList,
            baseInfo,
            setBaseInfo,
            flowData,
            setFlowData,
            setActiveTabs,
            mode,
            initialValue,
            flowMetaData,
            setActiveKey,
          }}
        >
          <div className={styles.modalBody}>
            <ConfigProvider
              theme={{
                components: {
                  Tabs: {
                    horizontalMargin: "0px",
                  },
                },
              }}
            >
              <Tabs
                type="card"
                items={TABS}
                activeKey={activeKey}
                onTabClick={(key: string) => {
                  // console.log(key);
                  setActiveKey(key);
                }}
              />
            </ConfigProvider>
          </div>
        </FormSettingContext.Provider>
      </div>
    </BasicModal>
  );
};

export default Setting;
