import { generateUUID } from "@/customForm/utils";

//反编译保存的数据
export function buildFlowList(data: any) {
  return data.map((item: any) => {
    if (item.elementId === "endEvent") {
      return {
        elementId: "endEvent",
        elementName: "结束节点",
        elementType: 4,
        nodeType: 4,
      };
    }
    if (item.nodeType.value === 1) {
      return {
        elementId: item.elementId,
        elementName: item.elementName,
        nodeType: 1,
        /** 处理内容 */
        examineKeys: item.examineKeys,
        assigneeKey: "applicant",
        elementType: 2,
        scopeOfApplication: item.scopeOfApplication,
        elementAlias: item.elementAlias,
        signType: 3,
      };
    }
    if (item.nodeType.value === 2) {
      return {
        elementId: item.elementId,
        elementName: item.elementName,
        approverList: item.approverList?.split(","),
        approverType: 1,
        nodeType: 2,
        icon: item.icon,
        /** 处理内容 */
        examineKeys: item.examineKeys,
        assigneeKey: "_approver_",
        elementType: 2,
        elementAlias: item.elementAlias,
        signType: 3,
      };
    }
    if (item.nodeType.value === 3) {
      return {
        elementId: item.elementId,
        elementName: item.elementName,
        approverList: item.approverList?.split(","),
        approverType: 1,
        nodeType: 3,
        icon: item.icon,
        /** 处理内容 */
        examineKeys: item.examineKeys,
        assigneeKey: "_approver_",
        elementType: 2,
        forwardAndReverseName: item.forwardAndReverseName.split(","),
        elementAlias: item.elementAlias,
        signType: 3,
      };
    }
  });
}

/** 反编译流程图 */
export function deserializeFlowChart(data: any[]) {
  const lineMap = new Map();
  data.forEach((item) => {
    if (item.from && item.to !== "endEvent") {
      lineMap.set(item.from, item);
    }
  });
  const nodeMap = new Map();
  data.forEach((item) => {
    nodeMap.set(item.elementId, item);
  });

  /** 找到开始节点 */
  const startNode = nodeMap.get("startEvent");
  const sortNodeList = [] as any[];
  const findNextNode = (node: any) => {
    const lineNode = lineMap.get(node.elementId);
    if (lineNode) {
      const to = lineNode.to;
      const nextNode = nodeMap.get(to);
      if (nextNode.elementType.value !== 3) {
        sortNodeList.push(nextNode);
      }
      findNextNode(nextNode);
    }
  };
  findNextNode(startNode);

  return [...sortNodeList, nodeMap.get("endEvent")];
}

/** 构造线节点 */
export function buildLineData(data: any) {
  const lineData = data
    .map((item: any, index: number) => {
      const nextNode = data[index + 1];
      if (nextNode) {
        if (item.nodeType === 1) {
          /** 处在申请节点时构造开始的以及下一步的连接线 */
          return [
            {
              elementId: generateUUID(),
              elementName: "连接线",
              elementType: 3,
              from: item.elementId,
              to: data[index + 1].elementId,
            },
            {
              elementId: generateUUID(),
              elementName: "开始连接线",
              elementType: 3,
              from: "startEvent",
              to: item.elementId,
            },
          ];
        }
        if (item.nodeType === 2) {
          return {
            elementId: generateUUID(),
            elementName: "连接线",
            elementType: 3,
            from: item.elementId,
            to: data[index + 1].elementId,
          };
        }
        if (item.nodeType === 3) {
          return [
            {
              approveResult: 2, //固定
              conditionType: 2, //固定
              elementId: generateUUID(), //随机生成
              elementName: "同意连接线",
              elementType: 3, //固定
              from: item.elementId, //来源节点
              to: nextNode.elementId, //目标节点
            },
            {
              approveResult: 3, //固定
              conditionType: 2, //固定
              elementId: generateUUID(), //随机生成
              elementName: "不同意连接线",
              elementType: 3,
              from: item.elementId, //来源节点
              to: "endEvent", //目标节点
            },
          ];
        }
      }
    })
    .filter((v: any) => v)
    .flat(1);

  return lineData;
}

/** 新增节点 */
export function getDefaultNodeByType(type?: 1 | 2 | 3 | 4) {
  switch (type) {
    case 1:
      return {
        elementId: generateUUID(),
        elementName: "申请人",
        nodeType: 1,
        /** 处理内容 */
        examineKeys: "all",
        assigneeKey: "applicant",
        elementType: 2,
        scopeOfApplication: "",
        elementAlias: "申请人",
        signType: 3,
      };
    case 2:
      return {
        elementId: generateUUID(),
        elementName: "办理节点",
        elementAlias: "办理节点",
        approverList: [],
        elementType: 2,
        icon: "",
        assigneeKey: "_approver_",
        approverType: 1,
        signType: 3,
        examineKeys: "all",
        nodeType: 2,
      };

    case 3:
      return {
        elementId: generateUUID(),
        elementName: "审批节点",
        elementAlias: "审批节点",
        approverType: 1,
        nodeType: 3,
        signType: 3,
        icon: "",
        assigneeKey: "_approver_",
        elementType: 2,
        approverList: [],
        forwardAndReverseName: ["同意", "驳回"],
        examineKeys: "all",
      };
    default:
      return {
        elementId: "endEvent",
        elementName: "结束节点",
        elementType: 4,
        nodeType: 4,
      };
  }
}
