import React, { createContext, useEffect, useState } from "react";

import ListItem from "./list-item";
import Login from "../../Login/login";
import SubExtend from "./subExtend";
import styles from "./index.module.css";
import SubmitApplication from "../SubmitApplication";
import service from "@/service";
import { buildTreeByGroupName } from "@/customForm/utils";
import HomeEmpty from "@/components/HomeEmpty";
interface ModalConfig {
  show: boolean;
  /** 原始数据 */
  metaData: any;
}

type ModalContextType = {
  modalOption: ModalConfig;
  setModalOption: React.Dispatch<React.SetStateAction<ModalConfig>>;
  subExtendModalOption: ModalConfig;
  setSubExtendModalOption: React.Dispatch<React.SetStateAction<ModalConfig>>;
};
const ModalContext = createContext<ModalContextType>({} as ModalContextType);

export function useModalConfigContext() {
  return React.useContext(ModalContext);
}

const UserMain: React.FC = () => {
  /** 弹窗配置 */
  const [modalOption, setModalOption] = useState<ModalConfig>({
    show: false,
    metaData: {},
  });
  const [subExtendModalOption, setSubExtendModalOption] = useState<ModalConfig>(
    {
      show: false,
      metaData: {},
    }
  );
  const [list, setList] = useState<Record<string, any>>({});

  useEffect(() => {
    service.applyService.getApplicationList().then((res) => {
      if (res.code === 200) {
        setList(buildTreeByGroupName(res.data.list));
      }
    });
  }, []);

  return (
    <ModalContext.Provider
      value={{
        modalOption,
        setModalOption,
        setSubExtendModalOption,
        subExtendModalOption,
      }}
    >
      <div className={styles.container}>
        <div className={styles.header}>
          <Login />
        </div>
        <div className={styles.contentWrapper}>
          <div className={styles.title}>审批通</div>

          <div className={styles.listContainer}>
            {Object.keys(list).length === 0 && <HomeEmpty />}
            {Object.keys(list).map((item) => (
              <ListItem data={list[item]} />
            ))}
          </div>
        </div>
        <SubExtend></SubExtend>
        {/** 提交申请的弹窗 */}
        <SubmitApplication />
      </div>
    </ModalContext.Provider>
  );
};

export default UserMain;
