import { Button, Space, message } from "antd";

import ArrowTag from "@/components/ArrowTag";
import React from "react";
import icon1 from "@/assets/images/icon/icon1.png";
import styles from "./index.module.css";
import { useModalConfigContext } from ".";
import useUserStore from "@/store/useUserStore";

const ListItem: React.FC<{ data: any }> = ({ data }) => {
  const { setModalOption, setSubExtendModalOption } = useModalConfigContext();
  const { userInfo } = useUserStore();

  const type = data?.child && data.child.length > 0 ? "group" : "item";
  /** 打开申请的弹窗 */
  const onApplyForClickHandler = () => {
    console.log(userInfo);
    if (userInfo?.id) {
      if (type === "group") {
        setSubExtendModalOption({
          show: true,
          metaData: data,
        });
        return;
      }
      setModalOption({
        show: true,
        metaData: data,
      });
    } else {
      message.warning("请先登录");
    }
  };

  return (
    <div className={styles.listItemWrapper}>
      <div className={styles.itemHeader}>
        <img src={icon1} alt="" style={{ width: 86, height: 86 }} />
        <div>
          <div className={styles.itemTitle}>
            {type === "group" ? data?.groupName : data?.thingName}
          </div>
          <Space>
            <ArrowTag
              text={data?.thingType ? "行政许可" : "行政备案"}
              style={{ color: "rgba(0, 119, 255, 1)" }}
            ></ArrowTag>
            <ArrowTag
              text={data?.implementingAgency}
              color="#FFE0B7"
              style={{
                color: "rgba(255, 128, 3, 1)",
              }}
            ></ArrowTag>
            <ArrowTag
              color="#D2D7E8"
              style={{ color: "rgba(109, 114, 132, 1)" }}
            >
              办理时长：
              <span style={{ color: "red" }}>
                {data?.promisedCompletionDeadline}&nbsp;
              </span>
              个工作日
            </ArrowTag>
          </Space>
        </div>

        <Space align="start">
          <Button type="primary" onClick={onApplyForClickHandler}>
            立即申请
          </Button>
        </Space>
      </div>
      <div className={styles.text}>
        {type === "group" ? data?.groupDesc : data?.legalBasis}
      </div>
    </div>
  );
};

export default ListItem;
