import { Button, Flex } from "antd";
import { useEffect, useState } from "react";

import BasicModal from "@/components/BasicModal";
import icon1 from "@/assets/images/icon/icon1.png";
import styles from "./subExtend.module.css";
import { useModalConfigContext } from ".";

const SubExtend = () => {
  const { subExtendModalOption, setModalOption } = useModalConfigContext();

  const [visible, setVisible] = useState(false);

  useEffect(() => {
    if (subExtendModalOption.show) {
      setVisible(true);
    }
  }, [subExtendModalOption]);

  const closeHandler = () => {
    setVisible(false);
    setModalOption({ show: false, metaData: {} });
  };

  const openSubmit = (data: any) => {
    setModalOption({
      show: true,
      metaData: data,
    });
  };
  return (
    <BasicModal
      visible={visible}
      width={1400}
      onClose={closeHandler}
      contentStyle={{
        borderRadius: 10,
      }}
    >
      <div className={styles.container}>
        <div className={styles.itemHeader}>
          <Flex align="center" gap={8}>
            <img src={icon1} alt="" style={{ width: 86, height: 86 }} />
            <div className={styles.itemTitle}>
              {subExtendModalOption?.metaData.groupName}
            </div>
          </Flex>
        </div>
        <div className={styles.descCard}>
          {subExtendModalOption?.metaData.groupDesc ?? "无"}
        </div>
        <div className={styles.menuWrapper}>
          {subExtendModalOption?.metaData.child?.map((item: any) => {
            return (
              <div className={styles.menuCard} key={item.id}>
                <Flex align="center" gap={8}>
                  <img src={icon1} alt="" style={{ width: 70, height: 70 }} />
                  <div className={styles.menuTitle}>{item.thingName}</div>
                </Flex>
                <div className={styles.text}>{item.legalBasis}</div>
                <Button
                  type="primary"
                  size="large"
                  onClick={openSubmit.bind(this, item)}
                >
                  立即申请
                </Button>
              </div>
            );
          })}
        </div>
      </div>
    </BasicModal>
  );
};

export default SubExtend;
