import { message, notification } from "antd";
import { ResponseError, extend } from "umi-request";
const errorHandler = function (error: ResponseError<any>) {
  const codeMap = {
    424: "请先登陆",
    // ....
  } as Record<number, string>;
  if (error.response) {
    // 请求已发送但服务端返回状态码非 2xx 的响应
    if (codeMap[error.response.status]) {
      if (error.data.message) {
        message.error(error.data.message);
      } else {
        message.error(codeMap[error.response.status]);
      }
    }
    // console.log(codeMap[error.data.status]);
  } else {
    // 请求初始化时出错或者没有响应返回的异常
    console.log(error.message);
  }

  throw error; // 如果throw. 错误将继续抛出.
};

const request = extend({
  /** 所有接口添加代理用的前缀 */
  prefix: "/apis",
  timeout: 10000,
  errorHandler,
});

/** 请求拦截器 */
request.interceptors.request.use(
  (url, options) => {
    let token = "";
    const pathname = location.pathname;
    if (pathname.includes("management")) {
      token = localStorage.getItem("admin_token") as any;
    }
    if (pathname.includes("apply")) {
      token = localStorage.getItem("user_token") as any;
    }

    return {
      url,
      options: {
        ...options,
        headers: {
          Authorization: token ? `Bearer ${token}` : "",
          ...(pathname.includes("apply") ? { "CLIENT-TOC": "Y" } : {}),
          ...options.headers,
        },
      },
    };
  },
  { global: true }
);

// 提前对响应做异常处理
request.interceptors.response.use((response) => {
  const codeMaps = {
    // 1: "请先登录",
  } as Record<number, string>;
  const responseClone = response.clone();
  /** 消费全局code */
  responseClone.json().then((resValue) => {
    if (codeMaps[resValue.code]) {
      notification.open({
        type: "error",
        message: codeMaps[resValue.code],
        duration: 1.5,
      });
    }
  });

  return response;
});

export default request;
