/** 构造个事件总线，用于及时通知各个层级的数据更新 */
class EventBus {
  handlers: Record<string, Array<(data?: any) => void>>;
  constructor() {
    this.handlers = {};
  }

  on(eventType: string, handler: (data?: any) => void) {
    if (!this.handlers[eventType]) {
      this.handlers[eventType] = [];
    }
    this.handlers[eventType].push(handler);
  }

  emit(eventType: string, data?: any) {
    const handlers = this.handlers[eventType];
    if (handlers) {
      handlers.forEach((handler: (arg0: any) => any) => handler(data));
    }
  }

  off(eventType: string, handler: (data?: any) => void) {
    const handlers = this.handlers[eventType];
    if (handlers) {
      this.handlers[eventType] = handlers.filter((h) => h !== handler);
    }
  }
}

const eventBus = new EventBus();

export default eventBus;
